@@ -5,7 +5,7 @@ import time
 from amuse.test.amusetest import TestWithMPI
 
 from amuse.community.fi.interface import FiInterface, Fi
-from amuse.ext.evrard_test import new_evrard_gas_sphere
+from amuse.ext.evrard_test import new_evrard_gas_sphere, MakeEvrardTest
 from amuse.ext.spherical_model import new_uniform_spherical_particle_distribution
 from amuse.units import nbody_system
 from amuse.units import units, constants
@@ -168,7 +168,7 @@ class TestFiInterface(TestWithMPI):
         x, y, z = gas.x.value_in(units.kpc), gas.y.value_in(units.kpc), gas.z.value_in(units.kpc)
         vx, vy, vz = [[0.0] * number_sph_particles] * 3
         u = [0.05] * number_sph_particles
-        indices = list(range(1,number_sph_particles+1))
+        indices = range(1,number_sph_particles+1)
         
         instance=FiInterface()
         instance.initialize_code()
@@ -399,7 +399,7 @@ class TestFi(TestWithMPI):
         convert_nbody = nbody_system.nbody_to_si(1.0 | units.MSun, 1.0 | units.AU)
         instance = Fi(convert_nbody)
         instance.initialize_code()
-        self.assertTrue('data/fi/input/' in instance.legacy_interface.get_fi_data_directory()['fi_data_directory'])
+        self.assertTrue('fi/data/input/' in instance.legacy_interface.get_fi_data_directory()['fi_data_directory'])
         self.assertEqual(instance.legacy_interface.get_fi_data_directory()['fi_data_directory'], 
             instance.get_data_directory()+'/')
         
