@@ -44,7 +44,6 @@ class CodeInterfaceWithConvertedUnitsTests(amusetest.TestCase):
         handler = instance.get_handler('METHOD')
         handler.add_method('add_to_length', (nbody_system.length,), nbody_system.length)
         
-        print(instance.mass)
         self.assertAlmostEqual(instance.mass.value_in(units.kg), 100.0, 10)
         
         
@@ -86,7 +85,7 @@ class CodeInterfaceWithConvertedUnitsTests(amusetest.TestCase):
            
         self.assertEqual(instance.return_an_errorcode(0), None)
         self.assertRaises(Exception, lambda : instance.return_an_errorcode(-1),
-            expected_message="Error when calling 'return_an_errorcode' of a 'InCodeComponentImplementation', errorcode is -1"
+            expected_message="Error when calling 'return_an_errorcode' of a '<class 'amuse.support.interface.InCodeComponentImplementation'>', errorcode is -1"
         )
         
         
@@ -153,7 +152,7 @@ class CodeInterfaceWithUnitsOnLegacyFunctionTests(amusetest.TestCase):
         instance = interface.InCodeComponentImplementation(original)
         
         instance.get_handler("LEGACY").legacy_interface = TestImplementation()
-        self.assertRaises(Exception,instance.return_error, " Error when calling 'echo_one' of a 'InCodeComponentImplementation', errorcode is -1")
+        self.assertRaises(Exception,instance.return_error, " Error when calling 'echo_one' of a '<class 'amuse.support.interface.InCodeComponentImplementation'>', errorcode is -1")
 
     def test4(self): 
         class TestImplementation(object):
@@ -268,7 +267,7 @@ class CodeInterfaceWithMethodsAndPropertiesTests(amusetest.TestCase):
         handler.add_method('get_state_error', (handler.NO_UNIT,), (units.m, units.m, units.kg, handler.ERROR_CODE))
         
         self.assertRaises(AmuseException, instance.get_state_error, 1, 
-            expected_message = "Error when calling 'get_state_error' of a 'InCodeComponentImplementation', errorcode is -1.0")
+            expected_message = "Error when calling 'get_state_error' of a '<class 'amuse.support.interface.InCodeComponentImplementation'>', errorcode is -1.0")
             
 
 class ClassWithState(object):
@@ -483,7 +482,7 @@ class CodeInterfaceTests(amusetest.TestCase):
         self.assertEqual(instance.get_name_of_current_state(), 'ZERO')
         self.assertEqual(instance.returns_2(), 2)
         self.assertRaises(Exception, instance.returns_3, 
-            expected_message = "While calling returns_3 of InCodeComponentImplementation: No transition from current state state 'TWO' to state 'THREE' possible")
+            expected_message = "While calling returns_3 of <class 'amuse.support.interface.InCodeComponentImplementation'>: No transition from current state state 'TWO' to state 'THREE' possible")
         
     def test9(self):
         original = ClassWithState()
@@ -706,7 +705,7 @@ class CodeInterfaceTests(amusetest.TestCase):
         
         self.assertEqual(instance.get_name_of_current_state(), 'ZERO')
         self.assertRaises( Exception, instance.returns_2, expected_message=
-         "While calling returns_2 of InCodeComponentImplementation: No transition from current state state 'ZERO' to state 'TWO' possible")
+         "While calling returns_2 of <class 'amuse.support.interface.InCodeComponentImplementation'>: No transition from current state state 'ZERO' to state 'TWO' possible")
 
         
 class CodeInterfaceWithUnitsAndStateTests(amusetest.TestCase):
@@ -797,11 +796,11 @@ class CodeInterfaceWithErrorHandlingTests(amusetest.TestCase):
         self.assertEqual(instance.get_mass(), 10.0 | units.m)
         original.errorcode = -2
         self.assertRaises(AmuseException, instance.get_mass, expected_message = 
-            "Error when calling 'get_mass' of a 'InCodeComponentImplementation', errorcode is -2, error is 'no such method'")
+            "Error when calling 'get_mass' of a '<class 'amuse.support.interface.InCodeComponentImplementation'>', errorcode is -2, error is 'no such method'")
             
         original.errorcode = -1
         self.assertRaises(AmuseException, instance.get_mass, expected_message = 
-            "Error when calling 'get_mass' of a 'InCodeComponentImplementation', errorcode is -1")
+            "Error when calling 'get_mass' of a '<class 'amuse.support.interface.InCodeComponentImplementation'>', errorcode is -1")
             
 
 class CodeInterfaceWithParticlesTests(amusetest.TestCase):
@@ -1279,8 +1278,6 @@ class TestGridWithBinding(amusetest.TestCase):
             return [numpy.asarray(i_s), numpy.asarray(j_s)]
         
         def get_a(self,i_s,j_s,k_s):
-            #print "indices:", i_s, j_s, k_s
-            #print "values:", numpy.asarray([(self.storage[i][j][k]) for i,j,k in zip(i_s, j_s, k_s)])
             return [numpy.asarray([(self.storage[i][j][k]) for i,j,k in zip(i_s, j_s, k_s)]),]
             
         def set_a(self, i_s, j_s, k_s, values):
@@ -1288,7 +1285,6 @@ class TestGridWithBinding(amusetest.TestCase):
             for i,j,k in zip(i_s, j_s, k_s):
                 self.storage[i][j][k] = values[index].value_in(units.m)
                 index += 1
-                print(index)
         
             
         
@@ -1301,10 +1297,7 @@ class TestGridWithBinding(amusetest.TestCase):
         handler = instance.get_handler('METHOD')
         handler.add_method('get_a',(handler.INDEX, handler.INDEX,handler.INDEX,), (units.kg,))
         handler.add_method('set_a',(handler.INDEX, handler.INDEX,handler.INDEX, units.kg,), ())
-      
-        print(instance.get_a([1],[2],[3]))
-        print([38] | units.kg)
-        
+              
         self.assertEqual(instance.get_a([1],[2],[3]), [38] | units.kg)
         
         handler = instance.get_handler('PARTICLES')
@@ -1412,9 +1405,7 @@ class TestGridWithBinding2(amusetest.TestCase):
         handler = instance.get_handler('METHOD')
         handler.add_method('get_a',(handler.INDEX, handler.INDEX,), (units.kg,))
         handler.add_method('set_a',(handler.INDEX, handler.INDEX, units.kg,), ())
-      
-        print(instance.get_a([1],[2]))
-        
+              
         self.assertEqual(instance.get_a([1],[2]), [7] | units.kg)
         
         handler = instance.get_handler('PARTICLES')
@@ -1427,7 +1418,6 @@ class TestGridWithBinding2(amusetest.TestCase):
         self.assertEqual(grid[1,2].mass, original.storage[1,2] | units.kg)
         self.assertEqual(len(grid[1].mass), len(original.storage[1]))
   
-        print(grid[1,1:].mass)   
         grid[1,1:].mass=[5. | units.kg]*4
 
         self.assertEqual(original.storage[1,1:],5)
