@@ -224,7 +224,7 @@ class TestParticleLinkToParticles(amusetest.TestCase):
     def test0(self):
         particles1 = datamodel.Particles(keys=[9,10,11,12])
         particles1.mass = [1,2,3,4] | units.kg
-        x = numpy.empty((10,), dtype=numpy.object)
+        x = numpy.empty((10,), dtype=object)
         index = numpy.asarray([1])
         x[index] = particles1
         print(x)
@@ -697,4 +697,4 @@ class TestGridPointLinkToGrid(amusetest.TestCase):
 
         for index in numpy.ndindex(*grid.shape):
             self.assertEqual(id(grid[index].container), id(grid))
-            self.assertEqual(grid[index].rho, (index[0] * 3 + index[1] + 2) | units.kg / units.m**3) 
\ No newline at end of file
+            self.assertEqual(grid[index].rho, (index[0] * 3 + index[1] + 2) | units.kg / units.m**3) 
